==> freecad_0.16.6712%2Bdfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Általános beállítások</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Általános OpenSCAD beállítások</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>OpenSCAD futtatható fájlok</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executeable</source>
      <translation>Az OpenSCAD fittatható fájlok elérési útvonala</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>OpenSCAD import</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Használja a NézetSzolgáltatót a Fa Nézetben</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Ha ez ki van jelölve akkor a Többmátrix tárgy Parametrikus lesz</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Használja a Többszörösmátrix tulajdonságot</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>A sokszög, hasáb vagy csonka maximális felületeinek száma. Ha az fn nagyobb mint ez az érték akkor ezt a tárgyat mint kört veszi figyelembe. Állítsa 0-ra a határtalansághoz</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>A sokszög (fn) maximális felületeinek száma</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>OpenSCAD export</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>a töredék maximum mérete</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>minimum angle for a fragment</source>
      <translation>minimum dőlésszög a töredékhez</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>Dőlésszög (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>minimum size of a fragment</source>
      <translation>a töredék minimum mérete</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>méret (fs)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>domborúság</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Háló visszamaradás</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Kiöblösödés</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>kiöblösödés</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Háromszögelési beállítások</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Ha ez be van jelölve, a fa nézetben a tulajdonságok jellegét meghatározzák az al értékek</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Hibakeresési információk a konzolra nyomtatva</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="141"/>
      <source>Convert Edges to Faces</source>
      <translation>Élek felületté konvertálása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="220"/>
      <source>Please select 3 objects first</source>
      <translation>Kérem válasszon ki először 3 tárgyat</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1118"/>
      <source>Unsupported Function</source>
      <translation>Nem támogatott funkció</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1118"/>
      <source>Press OK</source>
      <translation>OK-ra kattintson</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="264"/>
      <source>Add</source>
      <translation>Hozzáad</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="265"/>
      <source>Clear</source>
      <translation>Törlés</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="266"/>
      <source>as Mesh</source>
      <translation>a háló</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="267"/>
      <source>Add OpenSCAD Element</source>
      <translation>OpenSCAD elem hozzáadása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="340"/>
      <source>Perform</source>
      <translation>Végrehajt</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="341"/>
      <source>Mesh Boolean</source>
      <translation>Logikai háló</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="560"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Hiba, az alakzatok 2D-ek legyenek vagy mindkettő 3D legyen</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="91"/>
      <source>Unable to explode %s</source>
      <translation>Képtelen szétrobbantani ezt %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="382"/>
      <source>Add OpenSCAD Element...</source>
      <translation>OpenSCAD elem hozzáadása...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="384"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Adjunk hozzá egy OpenSCAD elemet egy OpenSCAD kód hozzáadásával és hajtsa végre az OpenSCAD binárist</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="118"/>
      <source>Color Shapes</source>
      <translation>Alakzatok színezése</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="120"/>
      <source>Color Shapes by validity and type</source>
      <translation>Alakzatok színezése az érvényesség és típus szerint</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="139"/>
      <source>Convert Edges To Faces</source>
      <translation>Élek konvertálása felületekké</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="200"/>
      <source>Expand Placements</source>
      <translation>Bontsa ki az elhelyezések</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="202"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Bontsa ki az összes elhelyezést lefelé a TulajdonságFában</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="100"/>
      <source>Explode Group</source>
      <translation>Csoport szétrobbantása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>remove fusion, apply placement to children and color randomly</source>
      <translation>távolítsa el a fúziót, alkalmazzon véletlenszerű elhelyezést a gyermekekre és a színre</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="417"/>
      <source>Hull</source>
      <translation>Héj</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="419"/>
      <source>Perform Hull</source>
      <translation>Héj létrehozás</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="181"/>
      <source>Increase Tolerance Feature</source>
      <translation>Növelje a tűréshatár tulajdonságot</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="183"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Tulajdonságot hoz létre, mely lehetővé teszi a tűréshatár növelését</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="396"/>
      <source>Mesh Boolean...</source>
      <translation>Logikai háló...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="398"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation.</source>
      <translation>Hálóként exportálja a tárgyakat és egy logikai művelet végrehajtásához használja az OpenSCAD-ot.</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="438"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="440"/>
      <source>Perform Minkowski</source>
      <translation>Minkowski végrehajtás</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="160"/>
      <source>Refine Shape Feature</source>
      <translation>Alakzat tulajdonság finomítása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="162"/>
      <source>Create Refine Shape Feature</source>
      <translation>Alakzat tulajdonság finomítás létrehozása</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="239"/>
      <source>Remove Objects and their Children</source>
      <translation>Objektum és az összes al objektuma eltávolítása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="241"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Eltávolítja a kijelölt objektumokat és minden al objektumár, melyek nem hivatkoznak más objektumokra</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Replace Object</source>
      <translation>Cserélje ki az objektumot</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="226"/>
      <source>Replace an object in the Feature Tree. Please select old, new and parent object</source>
      <translation>Visszahelyez egy objektumot a tulajdonság fában. Kérjük, válasszon régi, új, és a szülő objektumot</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="80"/>
      <source>OpenSCAD Part tools</source>
      <translation>OpenSCAD alkatrész eszközök</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="78"/>
      <source>OpenSCADTools</source>
      <translation>OpenSCADeszközök</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1%2Bdfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="hu" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Általános beállítások</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Általános OpenSCAD beállítások</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>OpenSCAD futtatható fájlok</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>OpenSCAD import</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Használja a NézetSzolgáltatót a Fa Nézetben</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Ha ez ki van jelölve akkor a Többmátrix tárgy Parametrikus lesz</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Használja a Többszörösmátrix tulajdonságot</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>A sokszög, hasáb vagy csonka maximális felületeinek száma. Ha az fn nagyobb mint ez az érték akkor ezt a tárgyat mint kört veszi figyelembe. Állítsa 0-ra a határtalansághoz</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>A sokszög (fn) maximális felületeinek száma</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>OpenSCAD export</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>a töredék maximum mérete</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>Dőlésszög (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>méret (fs)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>domborúság</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Háló visszamaradás</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Kiöblösödés</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>kiöblösödés</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Háromszögelési beállítások</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Ha ez be van jelölve, a fa nézetben a tulajdonságok jellegét meghatározzák az al értékek</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Hibakeresési információk a konzolra nyomtatva</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>Útvonal az OpenSCAD végrehajtásához</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Minimális szög egy részlethez</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Minimális méret egy részlethez</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="149"/>
      <source>Convert Edges to Faces</source>
      <translation>Élek felületté konvertálása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="309"/>
      <source>Please select 3 objects first</source>
      <translation>Kérem válasszon ki először 3 tárgyat</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Unsupported Function</source>
      <translation>Nem támogatott funkció</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Press OK</source>
      <translation>OK-ra kattintson</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="347"/>
      <source>Add</source>
      <translation>Hozzáad</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="348"/>
      <source>Clear</source>
      <translation>Törlés</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="349"/>
      <source>as Mesh</source>
      <translation>a háló</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="350"/>
      <source>Add OpenSCAD Element</source>
      <translation>OpenSCAD elem hozzáadása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="423"/>
      <source>Perform</source>
      <translation>Végrehajt</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="424"/>
      <source>Mesh Boolean</source>
      <translation>Logikai háló</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="623"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Hiba, az alakzatok 2D-ek legyenek vagy mindkettő 3D legyen</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>Unable to explode %s</source>
      <translation>Képtelen szétrobbantani ezt %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="464"/>
      <source>Add OpenSCAD Element...</source>
      <translation>OpenSCAD elem hozzáadása...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="468"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Adjunk hozzá egy OpenSCAD elemet egy OpenSCAD kód hozzáadásával és hajtsa végre az OpenSCAD binárist</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="126"/>
      <source>Color Shapes</source>
      <translation>Alakzatok színezése</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="129"/>
      <source>Color Shapes by validity and type</source>
      <translation>Alakzatok színezése az érvényesség és típus szerint</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="146"/>
      <source>Convert Edges To Faces</source>
      <translation>Élek konvertálása felületekké</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="291"/>
      <source>Expand Placements</source>
      <translation>Bontsa ki az elhelyezések</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="294"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Bontsa ki az összes elhelyezést lefelé a TulajdonságFában</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="110"/>
      <source>Explode Group</source>
      <translation>Csoport szétrobbantása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="113"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Távolítsa el a fúziót, alkalmazzon véletlenszerű elhelyezést az alárendeltekre és a színre</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="497"/>
      <source>Hull</source>
      <translation>Héj</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="500"/>
      <source>Perform Hull</source>
      <translation>Héj létrehozás</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="274"/>
      <source>Increase Tolerance Feature</source>
      <translation>Növelje a tűréshatár tulajdonságot</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="277"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Tulajdonságot hoz létre, mely lehetővé teszi a tűréshatár növelését</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="477"/>
      <source>Mesh Boolean...</source>
      <translation>Logikai háló...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="481"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Hálóként exportálja a tárgyakat és egy logikai művelet végrehajtásához használja az OpenSCAD-t</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="516"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="519"/>
      <source>Perform Minkowski</source>
      <translation>Minkowski végrehajtás</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="195"/>
      <source>Mirror Mesh Feature...</source>
      <translation>Tükrözött Háló Funkció...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="198"/>
      <source>Create Mirror Mesh Feature</source>
      <translation>Tükrözött Háló Funkció Létrehozása</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="165"/>
      <source>Refine Shape Feature</source>
      <translation>Alakzat tulajdonság finomítása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="168"/>
      <source>Create Refine Shape Feature</source>
      <translation>Alakzat tulajdonság finomítás létrehozása</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="324"/>
      <source>Remove Objects and their Children</source>
      <translation>Objektum és az összes al objektuma eltávolítása</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="327"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Eltávolítja a kijelölt objektumokat és minden al objektumár, melyek nem hivatkoznak más objektumokra</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="312"/>
      <source>Replace Object</source>
      <translation>Cserélje ki az objektumot</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="315"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Visszahelyez egy objektumot a tulajdonság fában. Kérjük, válasszon régi, új, és a szülő objektumot</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="254"/>
      <source>Resize Mesh Feature...</source>
      <translation>Hálótulajdonság átméretezése...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="258"/>
      <source>Create Resize Mesh Feature</source>
      <translation>Hálótulajdonság átméretezés létrehozása</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Scale Mesh Feature...</source>
      <translation>Hálótulajdonság szorzó...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="228"/>
      <source>Create Scale Mesh Feature</source>
      <translation>Hálótulajdonság szorzó létrehozása</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="83"/>
      <source>OpenSCAD Part tools</source>
      <translation>OpenSCAD alkatrész eszközök</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="81"/>
      <source>OpenSCADTools</source>
      <translation>OpenSCADeszközök</translation>
    </message>
  </context>
</TS>
